@@ -35,6 +35,7 @@ import time
 from typing import TYPE_CHECKING, Any, Generic, TypeVar, overload
 
 import aiohttp
+import aiohttp.client_exceptions
 import requests
 
 from . import data as data_classes
@@ -1129,7 +1130,9 @@ class Field:
         return f"({', '.join(f'{name}:{self.resolve_argument(value)}' for name, value in self.arguments.items())})"
 
     def resolve_argument(self, value: Union[Argument, Sequence[Argument]]) -> Any:
-        if isinstance(value, str):
+        if isinstance(value, enum.Enum):
+            return value.name
+        elif isinstance(value, str):
             return f'"{value}"'
         elif hasattr(value, "__iter__"):
             # pyright is not picking up the hasattr check
@@ -1346,12 +1349,14 @@ class Subscription(Generic[T]):
                 **self.filters_param,
             },
         ) as response:
-            data = await response.json()
-            logger.debug("Got response %s while requesting subscription channel", data)
-            if data.get("error") is not None:
-                raise errors.SubscribeError(data["error"])
-            return data["channel"]
-        raise errors.SubscribeError("Failed to request channel")
+            try:
+                data = await response.json()
+                logger.debug("Got response %s while requesting subscription channel", data)
+                if data.get("error") is not None:
+                    raise errors.SubscribeError(data["error"])
+                return data["channel"]
+            except aiohttp.client_exceptions.ContentTypeError as e:
+                raise errors.SubscribeError(e.message) from e
 
     async def unsubscribe(self) -> None:
         """Unsubscribe from the subscription"""
@@ -1488,13 +1493,14 @@ class Socket:
             logger.debug("Reconnected WS %s", self.ws)
             self.reconnecting = False
             self.connected.set()
-            for subscription in self.subscriptions:
-                subscription.succeeded.clear()
-                await self.subscribe(subscription)
         except BaseException as e:
             logger.debug("Failed to reconnect socket", exc_info=e)
             self.reconnecting = False
             raise e
+        for subscription in self.subscriptions:
+            subscription.succeeded.clear()
+            await self.subscribe(subscription)
+        logger.debug("Socket resubscribed")
 
     async def actual_run(self) -> None:
         while True:
